@@ -2,10 +2,12 @@
 """
 """
 
-__version__ = '0.1.130'
-
 # flake8: noqa
 
 from wheezy.validation.mixin import ValidationMixin
 from wheezy.validation.model import try_update_model
 from wheezy.validation.validator import Validator
+
+
+__all__ = ("ValidationMixin", "try_update_model", "Validator")
+__version__ = "0.1.146"
